@@ -5,7 +5,7 @@ use elbus::rpc::{self, RpcClient, RpcHandlers};
 use serde::{Deserialize, Serialize};
 use std::collections::HashMap;
 use std::fmt;
-#[cfg(feature = "extended-config")]
+#[cfg(feature = "extended-value")]
 use std::path::Path;
 use std::sync::Arc;
 use std::time::Duration;
@@ -215,7 +215,7 @@ impl Initial {
     pub fn config(&self) -> Option<&Value> {
         self.config.as_ref()
     }
-    #[cfg(feature = "extended-config")]
+    #[cfg(feature = "extended-value")]
     #[inline]
     pub async fn extend_config(&mut self, timeout: Duration, base: &Path) {
         self.config = self.config.extend(timeout, base).await;
